@@ -45,6 +45,7 @@ class Client(Callbacks, SocketHandler):
         self.account: objects.UserProfile = objects.UserProfile(None)
         self.profile: objects.UserProfile = objects.UserProfile(None)
         #print(self.device_id)
+        self.session=requests.Session()
         self.check_device(self.device_id)
         self.headerrs=headers.Headers(deviceId=self.device_id).headers   
     def parse_headers(self, data = None,deviceId:str=device_gen()):
@@ -265,7 +266,7 @@ class Client(Callbacks, SocketHandler):
             #print(r.json())
             response=r.json()["sid"]
 
-        else:
+        if proxy is False:
             data = json.dumps({
             "email": email,
             "v": 2,
@@ -275,10 +276,13 @@ class Client(Callbacks, SocketHandler):
             "action": "normal",
             "timestamp": int(timestamp() * 1000)
             })
-            response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath)
+            response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath).text
         
         self.run_socket()
-        if r.status_code != 200: return exceptions.CheckException(json.loads(response.text))
+        #print(response)
+        res=json.loads(response)
+        if res["api:statuscode"]!=0:
+            return exceptions.CheckException(json.loads(response))
 
         else:
             self.authenticated = True
@@ -291,7 +295,7 @@ class Client(Callbacks, SocketHandler):
             self.profile: objects.UserProfile = objects.UserProfile(self.json["userProfile"]).UserProfile
             headers.sid = self.sid
             self.start()
-            return r.status_code
+            return json.loads(response)
 
     def register(self, nickname: str, email: str, password: str, verificationCode: str, deviceId: str = device.device_id):
         """
